Chromatic Adaptation
====================

Chromatic Adaptation
--------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    chromatic_adaptation
    CHROMATIC_ADAPTATION_METHODS
    VIEWING_CONDITIONS_CMCCAT2000

**Dataset**

``colour``

.. autosummary::
    :toctree: generated/

    CHROMATIC_ADAPTATION_TRANSFORMS

Fairchild (1990)
----------------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_Fairchild1990

Fairchild (2020)
----------------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    CONDITIONS_DEGREE_OF_ADAPTATION_VK20
    matrix_chromatic_adaptation_vk20
    chromatic_adaptation_vK20

CIE 1994
--------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_CIE1994

CMCCAT2000
----------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_CMCCAT2000
    VIEWING_CONDITIONS_CMCCAT2000

**Ancillary Objects**

``colour.adaptation``

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_forward_CMCCAT2000
    chromatic_adaptation_inverse_CMCCAT2000
    InductionFactors_CMCCAT2000

Von Kries
---------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_VonKries
    CHROMATIC_ADAPTATION_TRANSFORMS

**Dataset**

``colour.adaptation``

.. autosummary::
    :toctree: generated/

    CAT_BRADFORD
    CAT_BIANCO2010
    CAT_PC_BIANCO2010
    CAT_CAT02_BRILL2008
    CAT_CAT02
    CAT_CAT16
    CAT_CMCCAT2000
    CAT_CMCCAT97
    CAT_FAIRCHILD
    CAT_SHARP
    CAT_VON_KRIES
    CAT_XYZ_SCALING

**Ancillary Objects**

``colour.adaptation``

.. autosummary::
    :toctree: generated/

    matrix_chromatic_adaptation_VonKries

Zhai and Luo (2018)
-------------------

``colour.adaptation``

.. currentmodule:: colour.adaptation

.. autosummary::
    :toctree: generated/

    chromatic_adaptation_Zhai2018
